==> qtjambi-quick-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiQuick/QSGTextureMaterial_shell.cpp <==
#include "QSGTextureMaterial_shell.h"
#include <QtJambi/Cast>

void deleter_QSGTextureMaterial(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGTextureMaterial")
    QSGTextureMaterial *_ptr = reinterpret_cast<QSGTextureMaterial *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGTextureMaterial_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGTextureMaterial_shell) ); }

jmethodID QSGTextureMaterial_shell::__shell_javaMethod(int pos) const { return QSGTextureMaterial_shell::__shell()->javaMethod(typeid(QSGTextureMaterial), pos); }

// emitting (writeShellConstructor)
QSGTextureMaterial_shell::QSGTextureMaterial_shell()
    : QSGTextureMaterial()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSGTextureMaterial::QSGTextureMaterial_shell()", QSGTextureMaterial_shell::__shell())
    QSGTextureMaterial_shell::__shell()->constructed(typeid(QSGTextureMaterial));
}

// emitting (writeShellDestructor)
QSGTextureMaterial_shell::~QSGTextureMaterial_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGTextureMaterial::~QSGTextureMaterial()", QSGTextureMaterial_shell::__shell())
    QSGTextureMaterial_shell::__shell()->destructed(typeid(QSGTextureMaterial));
}

void QSGTextureMaterial_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGTextureMaterial_shell*>(ptr)->QSGTextureMaterial_shell::__shell()->tryDeleteShell(typeid(QSGTextureMaterial));
}

// emitting Virtual overrides (virtualFunctions)
int QSGTextureMaterial_shell::compare(const QSGMaterial* other0) const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSGTextureMaterial::", QSGTextureMaterial_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            int  __qt_return_value = 0;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGTextureMaterial_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_other0 = qtjambi_cast<jobject>(__jni_env, other0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_other0);
                    jint __java_return_value = __jni_env->CallIntMethod(__java_this, method_id, __java_other0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<int>(__java_return_value);
                } else {
                    QSGTextureMaterial_shell::__shell()->warnForMethod("QSGTextureMaterial::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGTextureMaterial::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGOpaqueTextureMaterial::compare(other0);
        }
    }else{
        return QSGOpaqueTextureMaterial::compare(other0);
    }
}

QSGMaterialShader* QSGTextureMaterial_shell::createShader(QSGRendererInterface::RenderMode renderMode0) const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const", QSGTextureMaterial_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionInhibitor __qj_exnhandler;
            QSGMaterialShader*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGTextureMaterial_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_renderMode0 = qtjambi_cast<jobject>(__jni_env, renderMode0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_renderMode0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSGMaterialShader* >(__jni_env, __java_return_value);
                    if (__java_return_value == nullptr) {
                        JavaException::raiseNullPointerException(__jni_env, QStringLiteral("Method %1.createShader must not return null.").arg(QtJambiAPI::getObjectClassName(__jni_env, __java_this)) QTJAMBI_STACKTRACEINFO );
                    }
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                    if(!__qt_return_value)
                        JavaException::raiseNullPointerException(__jni_env, "QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const: Unexpected null pointer returned." QTJAMBI_STACKTRACEINFO );
                } else {
                    QSGTextureMaterial_shell::__shell()->warnForMethod("QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode(renderMode0));
        }
    }else{
        return QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode(renderMode0));
    }
}

QSGMaterialType* QSGTextureMaterial_shell::type() const
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("QSGTextureMaterial::type()const", QSGTextureMaterial_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSGMaterialType*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGTextureMaterial_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSGMaterialType* >(__jni_env, __java_return_value);
                } else {
                    QSGTextureMaterial_shell::__shell()->warnForMethod("QSGTextureMaterial::type()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGTextureMaterial::type()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGTextureMaterial::type();
        }
    }else{
        return QSGTextureMaterial::type();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QSGTextureMaterial_access::__qt_createShader_QSGRendererInterface_RenderMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint renderMode0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QSGRendererInterface::RenderMode __qt_renderMode0 = qtjambi_cast<QSGRendererInterface::RenderMode>(__jni_env, renderMode0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QSGMaterialShader* __qt_return_value = QSGTextureMaterial::createShader(__qt_renderMode0);
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QSGMaterialShader* __qt_return_value = createShader(__qt_renderMode0);
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

jobject QSGTextureMaterial_access::__qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QSGMaterialType* __qt_return_value = QSGTextureMaterial::type();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    } else {
        QSGMaterialType* __qt_return_value = type();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QSGTextureMaterial()
void __qt_construct_QSGTextureMaterial(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGTextureMaterial()")
    Q_UNUSED(__java_arguments)
    QSGTextureMaterial *__qt_this = new(__qtjambi_ptr) QSGTextureMaterial_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QSGTextureMaterial::QSGTextureMaterial()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTextureMaterial_initialize_1native__Lio_qt_quick_QSGTextureMaterial_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGTextureMaterial::QSGTextureMaterial()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGTextureMaterial, sizeof(QSGTextureMaterial_shell), typeid(QSGTextureMaterial), true, &deleter_QSGTextureMaterial, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGTextureMaterial_shell
void __qt_destruct_QSGTextureMaterial(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGTextureMaterial")
    reinterpret_cast<QSGTextureMaterial_shell*>(ptr)->~QSGTextureMaterial_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTextureMaterial_createShader_1native_1QSGRendererInterface_1RenderMode_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint renderMode0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QtJambiExceptionRaiser __qt_exceptionRaiser;
        const QSGTextureMaterial *__qt_this = QtJambiAPI::objectFromNativeId<QSGTextureMaterial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const", __qt_this)
        __java_return_value = static_cast<const QSGTextureMaterial_access*>(__qt_this)->__qt_createShader_QSGRendererInterface_RenderMode_constfct(__jni_env, __this_nativeId, renderMode0);
        __qt_exceptionRaiser.raise(__jni_env);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGTextureMaterial::type()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTextureMaterial_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGTextureMaterial *__qt_this = QtJambiAPI::objectFromNativeId<QSGTextureMaterial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTextureMaterial::type()const", __qt_this)
        __java_return_value = static_cast<const QSGTextureMaterial_access*>(__qt_this)->__qt_type_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSGTextureMaterial(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGTextureMaterial>("QSGTextureMaterial", "io/qt/quick/QSGTextureMaterial");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "compare", "(Lio/qt/quick/QSGMaterial;)I"),
        FunctionInfo(/* 1 */ "createShader", "(Lio/qt/quick/QSGRendererInterface$RenderMode;)Lio/qt/quick/QSGMaterialShader;"),
        FunctionInfo(/* 2 */ "type", "()Lio/qt/quick/QSGMaterialType;")});
    registerConstructorInfos(typeId, &__qt_destruct_QSGTextureMaterial, {
        ConstructorInfo(&__qt_construct_QSGTextureMaterial, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGTextureMaterial);
    registerSizeOfShell(typeId, sizeof(QSGTextureMaterial_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGOpaqueTextureMaterial, QSGTextureMaterial>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-quick-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiQuick/QSGTextureMaterial_shell.cpp <==
#include "QSGTextureMaterial_shell.h"
#include <QtJambi/Cast>

void deleter_QSGTextureMaterial(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QSGTextureMaterial")
    QSGTextureMaterial *_ptr = reinterpret_cast<QSGTextureMaterial *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QSGTextureMaterial_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QSGTextureMaterial_shell) ); }

jmethodID QSGTextureMaterial_oshell::__shell_javaMethod(int pos) const { return QSGTextureMaterial_shell::__shell()->javaMethod(typeid(QSGTextureMaterial), pos); }

// emitting (writeShellDestructor)
QSGTextureMaterial_shell::~QSGTextureMaterial_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QSGTextureMaterial::~QSGTextureMaterial()", this)
    QSGTextureMaterial_shell::__shell()->destructed(typeid(QSGTextureMaterial));
}

// emitting (writeShellConstructor)
QSGTextureMaterial_shell::QSGTextureMaterial_shell()
    : QSGTextureMaterial()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QSGTextureMaterial::QSGTextureMaterial_shell()", this)
    QSGTextureMaterial_shell::__shell()->constructed(typeid(QSGTextureMaterial));
}

void QSGTextureMaterial_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGTextureMaterial_shell*>(ptr)->QSGTextureMaterial_shell::__shell()->tryDeleteShell(typeid(QSGTextureMaterial));
}

void QSGTextureMaterial_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QSGTextureMaterial_oshell*>(ptr)->QSGTextureMaterial_oshell::__shell()->tryDeleteShell(typeid(QSGTextureMaterial));
}

// emitting Virtual overrides (virtualFunctions)
int QSGTextureMaterial_oshell::compare(const QSGMaterial* other0) const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QSGTextureMaterial::compare(const QSGMaterial*)const", this)
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            int  __qt_return_value = 0;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGTextureMaterial_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_other0 = qtjambi_cast<jobject>(__jni_env, other0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_other0);
                    jint __java_return_value = __jni_env->CallIntMethod(__java_this, method_id, __java_other0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<int>(__java_return_value);
                } else {
                    QSGTextureMaterial_shell::__shell()->warnForMethod("QSGTextureMaterial::compare(const QSGMaterial*)const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGTextureMaterial::compare(const QSGMaterial*)const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGOpaqueTextureMaterial::compare(other0);
        }
    }else{
        return QSGOpaqueTextureMaterial::compare(other0);
    }
}

QSGMaterialShader* QSGTextureMaterial_oshell::createShader(QSGRendererInterface::RenderMode renderMode0) const
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const", this)
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionInhibitor __qj_exnhandler;
            QSGMaterialShader*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGTextureMaterial_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_renderMode0 = qtjambi_cast<jobject>(__jni_env, renderMode0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_renderMode0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSGMaterialShader*>(__jni_env, __java_return_value);
                    if (__java_return_value == nullptr) {
                        JavaException::raiseNullPointerException(__jni_env, QStringLiteral("Method %1.createShader must not return null.").arg(QtJambiAPI::getObjectClassName(__jni_env, __java_this)) QTJAMBI_STACKTRACEINFO );
                    }
                    QtJambiAPI::setCppOwnershipAndInvalidate(__jni_env, __java_return_value);
                    if(!__qt_return_value)
                        JavaException::raiseNullPointerException(__jni_env, "QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const: Unexpected null pointer returned." QTJAMBI_STACKTRACEINFO );
                } else {
                    QSGTextureMaterial_shell::__shell()->warnForMethod("QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode(renderMode0));
        }
    }else{
        return QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode(renderMode0));
    }
}

QSGMaterialType* QSGTextureMaterial_oshell::type() const
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("QSGTextureMaterial::type()const", this)
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QSGMaterialType*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QSGTextureMaterial_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QSGMaterialType*>(__jni_env, __java_return_value);
                } else {
                    QSGTextureMaterial_shell::__shell()->warnForMethod("QSGTextureMaterial::type()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QSGTextureMaterial::type()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QSGTextureMaterial::type();
        }
    }else{
        return QSGTextureMaterial::type();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QSGTextureMaterial_access::__qt_createShader_QSGRendererInterface_RenderMode_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint renderMode0) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QSGRendererInterface::RenderMode __qt_renderMode0 = qtjambi_cast<QSGRendererInterface::RenderMode>(__jni_env, renderMode0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QSGMaterialShader* __qt_return_value = QSGTextureMaterial::createShader(__qt_renderMode0);
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QSGMaterialShader* __qt_return_value = createShader(__qt_renderMode0);
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

jobject QSGTextureMaterial_access::__qt_type_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QSGMaterialType* __qt_return_value = QSGTextureMaterial::type();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    } else {
        QSGMaterialType* __qt_return_value = type();
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QSGTextureMaterial()
void __qt_construct_QSGTextureMaterial(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool __qtjambi_has_overrides, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QSGTextureMaterial()")
    Q_UNUSED(__java_arguments)
    QSGTextureMaterial *__qt_this;
    if(__qtjambi_has_overrides)
        __qt_this = new(__qtjambi_ptr) QSGTextureMaterial_oshell();
    else
        __qt_this = new(__qtjambi_ptr) QSGTextureMaterial_shell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QSGTextureMaterial::QSGTextureMaterial()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTextureMaterial_initialize_1native__Lio_qt_quick_QSGTextureMaterial_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QSGTextureMaterial::QSGTextureMaterial()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QSGTextureMaterial, sizeof(QSGTextureMaterial_shell), typeid(QSGTextureMaterial), 0, true, &deleter_QSGTextureMaterial, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QSGTextureMaterial_shell
void __qt_destruct_QSGTextureMaterial(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QSGTextureMaterial")
    reinterpret_cast<QSGTextureMaterial_shell*>(ptr)->~QSGTextureMaterial_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTextureMaterial_createShader_1native_1QSGRendererInterface_1RenderMode_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint renderMode0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QtJambiExceptionRaiser __qt_exceptionRaiser;
        const QSGTextureMaterial *__qt_this = QtJambiAPI::objectFromNativeId<QSGTextureMaterial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTextureMaterial::createShader(QSGRendererInterface::RenderMode)const", __this_nativeId)
        __java_return_value = static_cast<const QSGTextureMaterial_access*>(__qt_this)->__qt_createShader_QSGRendererInterface_RenderMode_constfct(__jni_env, __this_nativeId, renderMode0);
        __qt_exceptionRaiser.raise(__jni_env);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QSGTextureMaterial::type()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_QSGTextureMaterial_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QSGTextureMaterial *__qt_this = QtJambiAPI::objectFromNativeId<QSGTextureMaterial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QSGTextureMaterial::type()const", __this_nativeId)
        __java_return_value = static_cast<const QSGTextureMaterial_access*>(__qt_this)->__qt_type_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QSGTextureMaterial(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QSGTextureMaterial>("QSGTextureMaterial", "io/qt/quick/QSGTextureMaterial");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "compare", "(Lio/qt/quick/QSGMaterial;)I"),
        FunctionInfo(/* 1 */ "createShader", "(Lio/qt/quick/QSGRendererInterface$RenderMode;)Lio/qt/quick/QSGMaterialShader;"),
        FunctionInfo(/* 2 */ "type", "()Lio/qt/quick/QSGMaterialType;")});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QSGTextureMaterial, {
        ConstructorInfo(&__qt_construct_QSGTextureMaterial, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QSGTextureMaterial);
    registerSizeOfShell(typeId, sizeof(QSGTextureMaterial_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QSGOpaqueTextureMaterial, QSGTextureMaterial>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
